get_muts

Function get_muts 

pub fn get_muts(tcx: TyCtxt<'_>, def_id: DefId) -> Vec<DefId>
Find &mut self methods (mutators) on the same struct as def_id.

A mutator is a method whose first parameter is a mutable reference to Self. These methods can change struct fields and affect subsequent invariant checks.